package main

import (
	"flag"
	"fmt"
	"log"

	"git.autistici.org/ale/autoradio"
	"git.autistici.org/ale/autoradio/fe"
	"git.autistici.org/ale/autoradio/instrumentation"
	"git.autistici.org/ale/autoradio/util"
)

var (
	domain      = flag.String("domain", "", "DNS domain to serve")
	publicIps   = util.IPList("ip", "Public IP for this machine (may be specified more than once)")
	dnsPort     = flag.Int("dns-port", 53, "DNS port")
	httpPort    = flag.Int("http-port", 80, "HTTP port")
	staticDir   = flag.String("static-dir", "/usr/share/autoradio/htdocs/static", "Static content directory")
	templateDir = flag.String("template-dir", "/usr/share/autoradio/htdocs/templates", "HTML templates directory")
	lbPolicy    = flag.String("lb-policy", "weighted", "Load balancing policy (weighted, leastloaded)")

	// Default DNS TTL (seconds).
	dnsTtl = 5
)

func main() {
	log.SetFlags(0)
	flag.Parse()

	if *domain == "" {
		log.Fatal("Must specify --domain")
	}

	instrumentation.NewCounter("redirectord.restarts").Incr()

	client := autoradio.NewClient(autoradio.NewEtcdClient(false))

	dnsRed := fe.NewDnsRedirector(client, *domain, util.IPListWithDefault(*publicIps, "127.0.0.1"), dnsTtl)
	dnsRed.Run(fmt.Sprintf(":%d", *dnsPort))

	red := fe.NewHttpRedirector(client, *domain, *lbPolicy)
	red.Run(fmt.Sprintf(":%d", *httpPort), *staticDir, *templateDir)
}
